==> svm-1.0.0-rc14-sources.jar: com/oracle/svm/core/posix/headers/darwin/DarwinSysctl.java <==
/*
 * Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.posix.headers.darwin;

import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;
import org.graalvm.nativeimage.c.CContext;
import org.graalvm.nativeimage.c.constant.CConstant;

import com.oracle.svm.core.posix.headers.PosixDirectives;

/** Declarations of method from <sys/sysctl.h>. */
@Platforms(Platform.DARWIN_AND_JNI.class)
@CContext(PosixDirectives.class)
public class DarwinSysctl {
    // { Allow names with underscores: Checkstyle: stop

    @CConstant
    public static native int CTL_KERN();

    @CConstant
    public static native int KERN_IPC();

    @CConstant
    public static native int KIPC_MAXSOCKBUF();

    @CConstant
    public static native int CTL_HW();

    @CConstant
    public static native int HW_MEMSIZE();

    // } Allow names with underscores: Checkstyle: resume
}

==> svm-19.2.1-sources.jar: com/oracle/svm/core/posix/headers/darwin/DarwinSysctl.java <==
/*
 * Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.posix.headers.darwin;

import org.graalvm.nativeimage.Platforms;
import org.graalvm.nativeimage.c.CContext;
import org.graalvm.nativeimage.c.constant.CConstant;

import com.oracle.svm.core.posix.headers.PosixDirectives;
import org.graalvm.nativeimage.impl.InternalPlatform;

/** Declarations of method from <sys/sysctl.h>. */
@Platforms(InternalPlatform.DARWIN_AND_JNI.class)
@CContext(PosixDirectives.class)
public class DarwinSysctl {
    // { Allow names with underscores: Checkstyle: stop

    @CConstant
    public static native int CTL_KERN();

    @CConstant
    public static native int KERN_IPC();

    @CConstant
    public static native int KIPC_MAXSOCKBUF();

    @CConstant
    public static native int CTL_HW();

    @CConstant
    public static native int HW_MEMSIZE();

    // } Allow names with underscores: Checkstyle: resume
}
